/**
 * @(#) NormalizedMessage.java
 *
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: NormalizedMessage.java 69 2006-01-17 16:00:26Z rmarins $
 * -------------------------------------------------------------------------
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.messaging;

/**
 * Represents a JBI Normalized Message. A normalized message consists of:
 * <ul>
 *   <li><b>Content</b>. The XML “payload” message, which conforms to the
 *   abstract WSDL message given in the service description. (WSDL 1.1-described
 *   messages are converted to a JBI-defined XML “wrapper” format.)
 *   <li><b>Attachments</b>. Extra (generally binary) attachments to the main
 *   message.
 *   <li><b>Security subject</b>. The security subject associated with the
 *   content.
 *   <li><b>Properties</b>. Other message-related data other than the
 *   first-class items listed above. Properties are name/value pairs. There are
 *   some JBI-defined names (and corresponding value types). This may be
 *   extended by components to include component-specific properties.
 * </ul>
 * 
 * @author JSR208 Expert Group
 */
public interface NormalizedMessage {

	/**
     * Add an attachment to this message.
     * 
     * @param id
     *            unique identifier for the attachment; must be non-null and
     *            non-empty
     * @param content
     *            attachment content; must be non-null
     * @throws MessagingException
     *             failed to add attachment
     */
    public void addAttachment(java.lang.String id,
            javax.activation.DataHandler content) throws MessagingException;

	/**
     * Retrieve an attachment to this message with the specified identifier.
     * 
     * @param id
     *            unique identifier for attachment; must be non-null and
     *            non-empty
     * @return DataHandler representing attachment content, or <code>null</code>
     *         if an attachment with the specified identifier is not found
     */
	public javax.activation.DataHandler getAttachment(java.lang.String id);

	/**
     * Returns a list of identifiers for all attachments to this message.
     * 
     * @return a Set of attachment identifier Strings; must be non-null; may be
     *         empty
     */
	public java.util.Set getAttachmentNames();

	/**
	 * Retrieve the content of this message.
	 * 
	 * @return message content; may be <code>null</code>
	 */
	public javax.xml.transform.Source getContent();

	/**
     * Retrieve a property from the message.
     * 
     * @param name
     *            property name; must be non-null and non-empty
     * @return property value, or <code>null</code> if the property does not
     *         exist or has no value
     */
	public java.lang.Object getProperty(java.lang.String name);

	/**
	 * Retrieve a set of property names for this message.
	 * 
	 * @return set of property names for this message; must be non-null; may be
	 *         empty
	 */
	public java.util.Set getPropertyNames();

	/**
     * Get the security subject associated with this message.
     * 
     * @return the security subject associated with this message;
     *         <code>null</code> if none.
     */
	public javax.security.auth.Subject getSecuritySubject();

	/**
	 * Removes the attachment from this message with the specified unique
	 * identifier.
	 * 
	 * @param id
	 *            attachment identifier; must be non-null and non-empty
	 * @throws MessagingException
	 *             failed to remove attachment or the attachment does not exist
	 */
	public void removeAttachment(java.lang.String id) throws MessagingException;

	/**
     * Set the content of this message.
     * 
     * @param content
     *            message content; may be null
     * @throws MessagingException
     *             failed to set content
     */
    public void setContent(javax.xml.transform.Source content)
            throws MessagingException;

	/**
	 * Set a property on the message.
	 * 
	 * @param name
	 *            property name; must be non-null and non-empty
	 * @param value
	 *            property value; may be <code>null</code>
	 */
	public void setProperty(java.lang.String name, java.lang.Object value);

	/**
	 * Set the security subject associated with this message.
	 * 
	 * @param subject
	 *            the security subject to associate with this message; may be
	 *            null
	 */ 		
	public void setSecuritySubject(javax.security.auth.Subject subject);
}
