<?xml version="1.0"?>
<!--
	Copyright (C) The MX4J Contributors.
	All rights reserved.
	
	This software is distributed under the terms of the MX4J License version 1.0.
	See the terms of the MX4J License in the documentation provided with this software.
	
	Author: Carlos Quiroz (tibu@users.sourceforge.net)
	Revision: $Revision: 76 $
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" indent="yes" encoding="ISO-8859-1" />
	<xsl:include href="common.xsl" />
	<xsl:include href="xalan-ext.xsl" />

	<xsl:param name="html.stylesheet">stylesheet.css</xsl:param>
	<xsl:param name="html.stylesheet.type">text/css</xsl:param>
	<xsl:param name="head.title">serverbydomain.title</xsl:param>

	<!-- Invoked when a query error is produced -->
	<xsl:template match="Domain" name="error">
		<xsl:for-each select="Exception">
			<tr>
				<td class="serverbydomain_domainline" colspan="5">
					<xsl:call-template name="str">
						<xsl:with-param name="id">serverbydomain.error.query</xsl:with-param>
						<xsl:with-param name="p0">
							<xsl:value-of select="@errorMsg" />
						</xsl:with-param>
					</xsl:call-template>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>

	<!-- Invoked to display each domain -->
	<xsl:template match="Domain" name="domain">
		<xsl:for-each select="Domain">
			<xsl:sort data-type="text" order="ascending" select="@name" />
			<xsl:choose>
				<xsl:when test="contains(@name, 'admin-impl')">
					<tr>
						<td class="serverbydomain_domainline" colspan="5">Administration Service</td>
						<xsl:call-template name="mbean" />
					</tr>
				</xsl:when>
				<xsl:when test="contains(@name, 'installation-impl')">
					<tr>
						<td class="serverbydomain_domainline" colspan="5">Installation Service</td>
						<xsl:call-template name="mbean" />
					</tr>
				</xsl:when>
				<xsl:when test="contains(@name, 'deployment-impl')">
					<tr>
						<td class="serverbydomain_domainline" colspan="5">Deployment Service</td>
						<xsl:call-template name="mbean" />
					</tr>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
		<tr>
			<td class="serverbydomain_domainline" colspan="5">Components</td>
			<xsl:call-template name="mbean" />
		</tr>
	</xsl:template>

	<!-- invoked for each mbean -->
	<xsl:template match="MBean" name="mbean">
		<tr width="100%">
			<td class="petals_domainline" colspan="5">Services</td>
		</tr>
		<xsl:for-each select="MBean">
			<xsl:sort data-type="text" order="ascending" select="@objectname" />
			<xsl:variable name="classtype">
				<xsl:if test="(position() mod 2)=1">darkline</xsl:if>
				<xsl:if test="(position() mod 2)=0">clearline</xsl:if>
			</xsl:variable>
			<xsl:variable name="objectname">
				<xsl:call-template name="uri-encode">
					<xsl:with-param name="uri" select="@objectname" />
				</xsl:call-template>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="contains(@objectname, 'admin-impl') and contains(@objectname, 'service')">
					<tr class="{$classtype}" width="100%">
						<td class="petals_row" colspan="5">
							<a href="mbean?objectname={$objectname}">Administration Service</a>
						</td>
					</tr>
				</xsl:when>
				<xsl:when test="contains(@objectname , 'installation-impl') and contains(@objectname , 'service')">
					<tr class="{$classtype}" width="100%">
						<td class="petals_row" colspan="5">
							<a href="mbean?objectname={$objectname}">Installation Service</a>
						</td>
					</tr>
					<tr width="100%"></tr>
					<tr width="100%">
						<td class="petals_domainline" colspan="5">Components</td>
					</tr>
				</xsl:when>
				<xsl:when test="contains(@objectname , 'deployment-impl') and contains(@objectname , 'service')">
					<tr class="{$classtype}" width="100%">
						<td class="petals_row" colspan="5">
							<a href="mbean?objectname={$objectname}">Deployment Service</a>
						</td>
					</tr>
				</xsl:when>
				<xsl:when test="contains(@objectname , 'type=binding,') or contains(@objectname , 'type=engine,') or contains(@objectname , 'type=installer,')">
					<tr class="{$classtype}" width="100%">
						<td width="90%" align="left" class="petals_row">
							<a href="mbean?objectname={$objectname}">
								<xsl:value-of select="@objectname" />
							</a>
						</td>
						<td width="10%" align="right" class="petals_row">
							<p>
								<a href="delete?objectname={$objectname}">
									<xsl:call-template name="str">
										<xsl:with-param name="id">serverbydomain.mbean.unregister</xsl:with-param>
									</xsl:call-template>
								</a>
							</p>
						</td>
					</tr>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

	<!-- Main template -->
	<xsl:template match="Server">
		<html>
			<xsl:call-template name="head" />
			<body>
				<table width="100%" cellpadding="0" cellspacing="0" border="0">
					<tr width="100%">
						<td>
							<xsl:call-template name="toprow" />
							<xsl:call-template name="tabs">
								<xsl:with-param name="selection">petals</xsl:with-param>
							</xsl:call-template>
							<xsl:variable name="query">
								<xsl:call-template name="str">
									<xsl:with-param name="id">serverbydomain.server.query</xsl:with-param>
								</xsl:call-template>
							</xsl:variable>
							<table width="100%" cellpadding="0" cellspacing="0" border="0">

								<tr>
									<td class="page_title">
										<xsl:call-template name="str">
											<xsl:with-param name="id">petals.title</xsl:with-param>
										</xsl:call-template>
									</td>
									<form action="serverbydomain">
										<td align="right" class="page_title">
											<xsl:call-template name="str">
												<xsl:with-param name="id">serverbydomain.server.filter</xsl:with-param>
											</xsl:call-template>
											<input type="text" name="querynames" value="*:*" />
											<input type="submit" value="{$query}" />
										</td>
									</form>
								</tr>
							</table>
							<table width="100%" cellpadding="0" cellspacing="0" border="0">
								<xsl:call-template name="mbean" />
								<xsl:call-template name="error" />
							</table>
							<xsl:call-template name="bottom" />
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>

