/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: AntTaskServiceAssemnly.java 09:12:57 ddesjardins $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.tools.ant.managers;

import javax.management.MBeanServerConnection;
import javax.management.remote.JMXConnector;

import org.apache.tools.ant.BuildException;
import org.objectweb.petals.tools.ant.util.JBIJMXConnectorUtil;

/**
 * This class gathers the action on a service assembly
 * 
 * @author ddesjardins - eBMWebsourcing
 */
public abstract class ServiceAssemblyAntTaskAbstract extends JBIAntTaskAbstract {

    /**
     * Action : shutdown a service assembly
     */
    protected static final String SHUTDOWN = "shutDown";

    /**
     * Action : start a service assembly
     */
    protected static final String START = "start";

    /**
     * Action : stop a service assembly
     */
    protected static final String STOP = "stop";

    /**
     * Action : undeploy a service assembly
     */
    protected static final String UNDEPLOY = "undeploy";

    /**
     * Name of the service assembly
     */
    protected String name;

    /**
     * Perform an action on a service assembly
     * @param action
     */
    protected void performAction(String action) {
        if (name == null) {
            throw new BuildException("Required attribute : name");
        }
        try {
            JMXConnector connector = JBIJMXConnectorUtil.getConnection(host,
                    port, username, password);
            MBeanServerConnection connection = connector
                    .getMBeanServerConnection();
            Object[] objects = new Object[1];
            objects[0] = name;
            String[] strings = new String[1];
            strings[0] = "java.lang.String";
            Object result = connection.invoke(JBIJMXConnectorUtil
                    .getDeploymentServiceMBeanName(connection), action,
                    objects, strings);
            if (result instanceof String) {
                // Extract the service assembly name
                String xml = (String) result;
                if (xml.indexOf("Successfully") > -1) {
                    String saName = "";
                    saName = xml.substring(xml.indexOf("<loc-param>") + 11, xml
                            .indexOf("</loc-param>"));
                    try {
                        log("Started service assembly name : " + saName);
                    } catch (NullPointerException e) {
                        // Exception thrown when execute outisde of the ant
                        // context
                    }
                } else {
                    try {
                        log("Problem during the " + action + " :\n"
                                + (String) result);
                    } catch (NullPointerException e) {
                        // Exception thrown when execute outisde of the ant
                        // context
                    }
                }
            }
            connector.close();
        } catch (Exception e) {
            if (Boolean.parseBoolean(failOnError)) {
                throw new BuildException(e.getMessage(), e.getCause());
            }
        }
    }

    public void setName(String name) {
        this.name = name;
    }

}
